JwtToken class

In its compact form, JSON Web Tokens consist of three parts separated by dots (.), which are:

  • Header
  • Payload
  • Signature Therefore, a JWT typically looks like the following: xxxxx.yyyyy.zzzzz

Constructors

JwtToken()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

getExpirationDate(String token) → DateTime
Identifies the expiration time on or after which the JWT must not be accepted for processing.
getTokenTime(String token) → Duration
Identifies the time at which the JWT was issued.
The header typically consists of two parts: the type of the token, which is JWT, and the signing algorithm being used, such as HMAC SHA256 or RSA.
isExpired(String token) → bool
Checks when the JWT must not be accepted for processing.
payload(String token) → Map<String, dynamic>
The second part of the token is the payload, which contains the claims. Claims are statements about an entity and additional data. There are three types of claims: registered, public, and private claims.